# Welcome to Connect Extension Utils Library !


This repository extend EaaS's out-of-box functionality providing a set of common utilities that can be reused between different extensions.



## License

**Connect Extension Utils Library** is licensed under the *Apache Software License 2.0* license.
